@@ -3,7 +3,7 @@
  *  Module    : nntplib.c
  *  Author    : S. Barber & I. Lea
  *  Created   : 1991-01-12
- *  Updated   : 2016-02-13
+ *  Updated   : 2016-05-27
  *  Notes     : NNTP client routines taken from clientlib.c 1.5.11 (1991-02-10)
  *  Copyright : (c) Copyright 1991-99 by Stan Barber & Iain Lea
  *              Permission is hereby granted to copy, reproduce, redistribute
@@ -1025,7 +1025,7 @@ check_extensions(
 			nntp_caps.list_distributions = FALSE;
 			nntp_caps.list_moderators = FALSE;
 			nntp_caps.list_counts = FALSE;
-			nntp_caps.xpat = FALSE;
+			nntp_caps.xpat = TRUE; /* only used in select.c:lookup_msgid(); toggles to false if fails, INN > 2.7.0 announces it */
 			nntp_caps.hdr = FALSE;
 			nntp_caps.hdr_cmd = NULL;
 			nntp_caps.over = FALSE;
@@ -1194,7 +1194,7 @@ check_extensions(
 								nntp_caps.sasl |= SASL_LOGIN;
 							}
 						}
-					} else if (!strncasecmp(ptr, "COMPRESS", 8)) { /* draft-murchison-nntp-compress-02.txt */
+					} else if (!strncasecmp(ptr, "COMPRESS", 8)) { /* draft-murchison-nntp-compress-03 */
 						d = ptr + 8;
 						d = strpbrk(d, " \t");
 						while (d != NULL && (d + 1 < (ptr + strlen(ptr)))) {
@@ -1211,6 +1211,7 @@ check_extensions(
 					else if (!strcasecmp(ptr, "STREAMING"))
 						nntp_caps.streaming = TRUE;
 #		endif /* 0 */
+				/* XZVER, XZHDR, ... */
 				} else
 					nntp_caps.type = NONE;
 			}
@@ -1562,7 +1563,6 @@ nntp_open(
 					break;
 			}
 		}
-#	ifdef XHDR_XREF
 		for (i = 0, j = 0; i < 2 && j >= 0; i++) {
 			j = new_nntp_command(&xhdr_cmds[i], ERR_CMDSYN, line, sizeof(line));
 			switch (j) {
@@ -1586,7 +1586,18 @@ nntp_open(
 					break;
 			}
 		}
-#	endif /* XHDR_XREF */
+		/* no XPAT probing here, we do it in select.c:lookup_msgid() as that's the only place we use it */
+		nntp_caps.xpat = TRUE;
+#		if 0
+		switch (new_nntp_command("XPAT Newsgroups <0> *", ERR_NOART, line, sizeof(line))) {
+			case ERR_NOART:
+				nntp_caps.xpat = TRUE;
+				break;
+
+			default:
+				break;
+		}
+#		endif /* 0 */
 	} else {
 		if (!nntp_caps.over_cmd) {
 			/*
@@ -1611,7 +1622,6 @@ nntp_open(
 					break;
 			}
 		}
-#	ifdef XHDR_XREF
 		if (!nntp_caps.hdr_cmd) {
 			/*
 			 * CAPABILITIES didn't mention HDR or XHDR, try XHDR
@@ -1635,7 +1645,6 @@ nntp_open(
 					break;
 			}
 		}
-#	endif /* XHDR_XREF */
 	}
 
 	if (!nntp_caps.over_cmd) {
@@ -1729,7 +1738,7 @@ get_only_respcode(
 		debug_print_file("NNTP", "<<<%s%s", logtime(), ptr);
 #	endif /* DEBUG */
 	respcode = (int) strtol(ptr, &end, 10);
-	if (end == ptr)
+	if (end == ptr) /* no leading numbers in response */
 		respcode = -1;
 	DEBUG_IO((stderr, "get_only_respcode(%d)\n", respcode));
 
@@ -1764,7 +1773,7 @@ get_only_respcode(
 			debug_print_file("NNTP", "<<<%s%s", logtime(), ptr);
 #	endif /* DEBUG */
 		respcode = (int) strtol(ptr, &end, 10);
-		if (end == ptr)
+		if (end == ptr) /* no leading numbers in response */
 			respcode = -1;
 		DEBUG_IO((stderr, "get_only_respcode(%d)\n", respcode));
 	}
